| Title: | Educational Statistics Tables and Graphs |
|---|---|
| Description: | Provides Spanish-language educational tools for descriptive statistics, probability calculations, frequency tables, and graphics. The package is designed for introductory statistics workflows and returns printable summaries, tables, and optional 'ggplot2' visualizations. The graphical tools build on the grammar of graphics described by Wickham (2016, ISBN:978-3-319-24277-4). |
| Authors: | Fredy Santiago Flores Espinoza [aut, cre] |
| Maintainer: | Fredy Santiago Flores Espinoza <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.1.0 |
| Built: | 2026-07-07 08:17:34 UTC |
| Source: | https://github.com/cran/mundoLindey |
Spanish-language educational tools for descriptive statistics, probability calculations, frequency tables, and graphics.
datos <- c(8.5, 9.2, 10.1, 11.4, 12.8, 13.1, 14.7, 15.2, 16.9, 18.3) tabla <- lindey_frecuencia_agrupada(datos, mostrar = FALSE) stopifnot(inherits(tabla, "lindey_frecuencia_agrupada")) variables <- lindey_tipo_variable(data.frame(nota = datos), "nota", mostrar = FALSE) stopifnot(inherits(variables, "lindey_tipo_variable"))datos <- c(8.5, 9.2, 10.1, 11.4, 12.8, 13.1, 14.7, 15.2, 16.9, 18.3) tabla <- lindey_frecuencia_agrupada(datos, mostrar = FALSE) stopifnot(inherits(tabla, "lindey_frecuencia_agrupada")) variables <- lindey_tipo_variable(data.frame(nota = datos), "nota", mostrar = FALSE) stopifnot(inherits(variables, "lindey_tipo_variable"))
Creates a 'ggplot2' graphic from a frequency-table result produced by this package.
lindey_barras_nominal( resultado, y = "fi", colores = "ejecutivo", color_borde = "white", ancho_borde = 0.7, ancho_barra = 0.72, alpha = 0.95, ordenar = TRUE, orden = "desc", horizontal = "auto", top_n = NULL, agrupar_otros = FALSE, etiqueta_otros = "Otros", leyenda = FALSE, titulo_leyenda = NULL, mostrar_valores = TRUE, etiqueta = "auto", posicion_etiqueta = "fuera", color_texto = "#334155", color_texto_dentro = "white", resaltar_moda = TRUE, color_moda_borde = "#0F172A", ancho_moda_borde = 1.2, mostrar_linea_promedio = FALSE, color_linea_promedio = "#64748B", tipo_linea_promedio = "dashed", titulo = NULL, subtitulo = NULL, eje_x = NULL, eje_y = NULL, caption = "Elaborado con Mundo LINDEY", rotar_etiquetas_x = FALSE, expandir_y = 0.15, base_size = 12, fondo = "blanco" )lindey_barras_nominal( resultado, y = "fi", colores = "ejecutivo", color_borde = "white", ancho_borde = 0.7, ancho_barra = 0.72, alpha = 0.95, ordenar = TRUE, orden = "desc", horizontal = "auto", top_n = NULL, agrupar_otros = FALSE, etiqueta_otros = "Otros", leyenda = FALSE, titulo_leyenda = NULL, mostrar_valores = TRUE, etiqueta = "auto", posicion_etiqueta = "fuera", color_texto = "#334155", color_texto_dentro = "white", resaltar_moda = TRUE, color_moda_borde = "#0F172A", ancho_moda_borde = 1.2, mostrar_linea_promedio = FALSE, color_linea_promedio = "#64748B", tipo_linea_promedio = "dashed", titulo = NULL, subtitulo = NULL, eje_x = NULL, eje_y = NULL, caption = "Elaborado con Mundo LINDEY", rotar_etiquetas_x = FALSE, expandir_y = 0.15, base_size = 12, fondo = "blanco" )
resultado |
A result object returned by a mundoLindey frequency-table function. |
y |
Column or measure to show on the y-axis. |
colores |
Color palette name or vector of colors. |
color_borde |
Argument used by 'color_borde'. |
ancho_borde |
Argument used by 'ancho_borde'. |
ancho_barra |
Argument used by 'ancho_barra'. |
alpha |
Argument used by 'alpha'. |
ordenar |
Argument used by 'ordenar'. |
orden |
Argument used by 'orden'. |
horizontal |
Argument used by 'horizontal'. |
top_n |
Argument used by 'top_n'. |
agrupar_otros |
Argument used by 'agrupar_otros'. |
etiqueta_otros |
Argument used by 'etiqueta_otros'. |
leyenda |
Argument used by 'leyenda'. |
titulo_leyenda |
Argument used by 'titulo_leyenda'. |
mostrar_valores |
Argument used by 'mostrar_valores'. |
etiqueta |
Argument used by 'etiqueta'. |
posicion_etiqueta |
Argument used by 'posicion_etiqueta'. |
color_texto |
Argument used by 'color_texto'. |
color_texto_dentro |
Argument used by 'color_texto_dentro'. |
resaltar_moda |
Argument used by 'resaltar_moda'. |
color_moda_borde |
Argument used by 'color_moda_borde'. |
ancho_moda_borde |
Argument used by 'ancho_moda_borde'. |
mostrar_linea_promedio |
Argument used by 'mostrar_linea_promedio'. |
color_linea_promedio |
Argument used by 'color_linea_promedio'. |
tipo_linea_promedio |
Argument used by 'tipo_linea_promedio'. |
titulo |
Plot title. |
subtitulo |
Plot subtitle. |
eje_x |
Argument used by 'eje_x'. |
eje_y |
Argument used by 'eje_y'. |
caption |
Plot caption. |
rotar_etiquetas_x |
Argument used by 'rotar_etiquetas_x'. |
expandir_y |
Argument used by 'expandir_y'. |
base_size |
Argument used by 'base_size'. |
fondo |
Argument used by 'fondo'. |
An R object; see the function output for details.
mundoLindey
tabla <- lindey_frecuencia_nominal(c("A", "B", "A", "C"), mostrar = FALSE) grafico <- lindey_barras_nominal(tabla) stopifnot(inherits(grafico, "lindey_grafico"))tabla <- lindey_frecuencia_nominal(c("A", "B", "A", "C"), mostrar = FALSE) grafico <- lindey_barras_nominal(tabla) stopifnot(inherits(grafico, "lindey_grafico"))
Creates a 'ggplot2' graphic from a frequency-table result produced by this package.
lindey_bastones_discreto( resultado, y = "fi", color_bastones = "lindey", color_puntos = NULL, color_moda = "#0F172A", grosor_baston = 1.15, tamano_puntos = 4, forma_puntos = 21, relleno_puntos = "white", mostrar_puntos = TRUE, mostrar_valores = TRUE, etiqueta = "auto", resaltar_moda = TRUE, mostrar_linea_base = TRUE, color_linea_base = "#CBD5E1", titulo = NULL, subtitulo = NULL, eje_x = NULL, eje_y = NULL, caption = "Elaborado con Mundo LINDEY", rotar_etiquetas_x = FALSE, expandir_y = 0.15, base_size = 12, fondo = "blanco" )lindey_bastones_discreto( resultado, y = "fi", color_bastones = "lindey", color_puntos = NULL, color_moda = "#0F172A", grosor_baston = 1.15, tamano_puntos = 4, forma_puntos = 21, relleno_puntos = "white", mostrar_puntos = TRUE, mostrar_valores = TRUE, etiqueta = "auto", resaltar_moda = TRUE, mostrar_linea_base = TRUE, color_linea_base = "#CBD5E1", titulo = NULL, subtitulo = NULL, eje_x = NULL, eje_y = NULL, caption = "Elaborado con Mundo LINDEY", rotar_etiquetas_x = FALSE, expandir_y = 0.15, base_size = 12, fondo = "blanco" )
resultado |
A result object returned by a mundoLindey frequency-table function. |
y |
Column or measure to show on the y-axis. |
color_bastones |
Argument used by 'color_bastones'. |
color_puntos |
Argument used by 'color_puntos'. |
color_moda |
Argument used by 'color_moda'. |
grosor_baston |
Argument used by 'grosor_baston'. |
tamano_puntos |
Argument used by 'tamano_puntos'. |
forma_puntos |
Argument used by 'forma_puntos'. |
relleno_puntos |
Argument used by 'relleno_puntos'. |
mostrar_puntos |
Argument used by 'mostrar_puntos'. |
mostrar_valores |
Argument used by 'mostrar_valores'. |
etiqueta |
Argument used by 'etiqueta'. |
resaltar_moda |
Argument used by 'resaltar_moda'. |
mostrar_linea_base |
Argument used by 'mostrar_linea_base'. |
color_linea_base |
Argument used by 'color_linea_base'. |
titulo |
Plot title. |
subtitulo |
Plot subtitle. |
eje_x |
Argument used by 'eje_x'. |
eje_y |
Argument used by 'eje_y'. |
caption |
Plot caption. |
rotar_etiquetas_x |
Argument used by 'rotar_etiquetas_x'. |
expandir_y |
Argument used by 'expandir_y'. |
base_size |
Argument used by 'base_size'. |
fondo |
Argument used by 'fondo'. |
An R object; see the function output for details.
mundoLindey
tabla <- lindey_frecuencia_discreto(c(1, 1, 2, 2, 3, 4), mostrar = FALSE) grafico <- lindey_bastones_discreto(tabla) stopifnot(inherits(grafico, "lindey_grafico"))tabla <- lindey_frecuencia_discreto(c(1, 1, 2, 2, 3, 4), mostrar = FALSE) grafico <- lindey_bastones_discreto(tabla) stopifnot(inherits(grafico, "lindey_grafico"))
Calculates measures of dispersion for grouped data.
lindey_dispersion_agrupada( resultado, tipo = c("muestra", "poblacion"), decimales = 4, mostrar = TRUE )lindey_dispersion_agrupada( resultado, tipo = c("muestra", "poblacion"), decimales = 4, mostrar = TRUE )
resultado |
A result object returned by a mundoLindey frequency-table function. |
tipo |
Type of calculation or display to use. |
decimales |
Number of decimal places used in displayed results. |
mostrar |
Logical value indicating whether to print the formatted summary. |
An R object; see the function output for details.
mundoLindey
datos <- c(8.5, 9.2, 10.1, 11.4, 12.8, 13.1, 14.7, 15.2, 16.9, 18.3) tabla <- lindey_frecuencia_agrupada(datos, mostrar = FALSE) dispersion <- lindey_dispersion_agrupada(tabla, mostrar = FALSE) stopifnot(inherits(dispersion, "lindey_dispersion_agrupada"))datos <- c(8.5, 9.2, 10.1, 11.4, 12.8, 13.1, 14.7, 15.2, 16.9, 18.3) tabla <- lindey_frecuencia_agrupada(datos, mostrar = FALSE) dispersion <- lindey_dispersion_agrupada(tabla, mostrar = FALSE) stopifnot(inherits(dispersion, "lindey_dispersion_agrupada"))
Summarizes or visualizes distribution shape for grouped data.
lindey_forma_agrupada( dispersion, decimales = 4, tol_asimetria = 0.1, tol_curtosis = 0.1, correccion_muestral = TRUE, mostrar = TRUE )lindey_forma_agrupada( dispersion, decimales = 4, tol_asimetria = 0.1, tol_curtosis = 0.1, correccion_muestral = TRUE, mostrar = TRUE )
dispersion |
A result object returned by 'lindey_dispersion_agrupada()'. |
decimales |
Number of decimal places used in displayed results. |
tol_asimetria |
Argument used by 'tol_asimetria'. |
tol_curtosis |
Argument used by 'tol_curtosis'. |
correccion_muestral |
Argument used by 'correccion_muestral'. |
mostrar |
Logical value indicating whether to print the formatted summary. |
An R object; see the function output for details.
mundoLindey
datos <- c(8.5, 9.2, 10.1, 11.4, 12.8, 13.1, 14.7, 15.2, 16.9, 18.3) tabla <- lindey_frecuencia_agrupada(datos, mostrar = FALSE) dispersion <- lindey_dispersion_agrupada(tabla, mostrar = FALSE) forma <- lindey_forma_agrupada(dispersion, mostrar = FALSE) stopifnot(inherits(forma, "lindey_forma_agrupada"))datos <- c(8.5, 9.2, 10.1, 11.4, 12.8, 13.1, 14.7, 15.2, 16.9, 18.3) tabla <- lindey_frecuencia_agrupada(datos, mostrar = FALSE) dispersion <- lindey_dispersion_agrupada(tabla, mostrar = FALSE) forma <- lindey_forma_agrupada(dispersion, mostrar = FALSE) stopifnot(inherits(forma, "lindey_forma_agrupada"))
Summarizes or visualizes distribution shape for grouped data.
lindey_forma_plot( forma, decimales = 3, titulo = "Forma de la distribuci\u00F3n", mostrar_referencia_normal = TRUE, color_curva = "#D97706", color_relleno = "#F8E7C7", color_referencia = "#6B7280", color_texto = "#111827", mostrar = TRUE )lindey_forma_plot( forma, decimales = 3, titulo = "Forma de la distribuci\u00F3n", mostrar_referencia_normal = TRUE, color_curva = "#D97706", color_relleno = "#F8E7C7", color_referencia = "#6B7280", color_texto = "#111827", mostrar = TRUE )
forma |
A result object returned by 'lindey_forma_agrupada()'. |
decimales |
Number of decimal places used in displayed results. |
titulo |
Plot title. |
mostrar_referencia_normal |
Argument used by 'mostrar_referencia_normal'. |
color_curva |
Argument used by 'color_curva'. |
color_relleno |
Argument used by 'color_relleno'. |
color_referencia |
Argument used by 'color_referencia'. |
color_texto |
Argument used by 'color_texto'. |
mostrar |
Logical value indicating whether to print the formatted summary. |
An R object; see the function output for details.
mundoLindey
datos <- c(8.5, 9.2, 10.1, 11.4, 12.8, 13.1, 14.7, 15.2, 16.9, 18.3) tabla <- lindey_frecuencia_agrupada(datos, mostrar = FALSE) dispersion <- lindey_dispersion_agrupada(tabla, mostrar = FALSE) forma <- lindey_forma_agrupada(dispersion, mostrar = FALSE) grafico <- lindey_forma_plot(forma, mostrar = FALSE) stopifnot(inherits(grafico, "ggplot"))datos <- c(8.5, 9.2, 10.1, 11.4, 12.8, 13.1, 14.7, 15.2, 16.9, 18.3) tabla <- lindey_frecuencia_agrupada(datos, mostrar = FALSE) dispersion <- lindey_dispersion_agrupada(tabla, mostrar = FALSE) forma <- lindey_forma_agrupada(dispersion, mostrar = FALSE) grafico <- lindey_forma_plot(forma, mostrar = FALSE) stopifnot(inherits(grafico, "ggplot"))
Creates Spanish-language frequency tables for grouped, discrete, or nominal data.
lindey_frecuencia_agrupada( data, variable = NULL, k = NULL, amplitud = NULL, metodo = "sturges", inicio = NULL, decimales_amplitud = "auto", decimales_intervalo = "auto", decimales_porcentaje = 2, mostrar = TRUE )lindey_frecuencia_agrupada( data, variable = NULL, k = NULL, amplitud = NULL, metodo = "sturges", inicio = NULL, decimales_amplitud = "auto", decimales_intervalo = "auto", decimales_porcentaje = 2, mostrar = TRUE )
data |
A vector or data frame containing the data to analyze. |
variable |
Optional variable name or column to analyze when 'data' is a data frame. |
k |
Argument used by 'k'. |
amplitud |
Argument used by 'amplitud'. |
metodo |
Argument used by 'metodo'. |
inicio |
Argument used by 'inicio'. |
decimales_amplitud |
Argument used by 'decimales_amplitud'. |
decimales_intervalo |
Argument used by 'decimales_intervalo'. |
decimales_porcentaje |
Argument used by 'decimales_porcentaje'. |
mostrar |
Logical value indicating whether to print the formatted summary. |
An R object; see the function output for details.
mundoLindey
datos <- c(8.5, 9.2, 10.1, 11.4, 12.8, 13.1, 14.7, 15.2, 16.9, 18.3) tabla <- lindey_frecuencia_agrupada(datos, mostrar = FALSE) stopifnot(inherits(tabla, "lindey_frecuencia_agrupada"))datos <- c(8.5, 9.2, 10.1, 11.4, 12.8, 13.1, 14.7, 15.2, 16.9, 18.3) tabla <- lindey_frecuencia_agrupada(datos, mostrar = FALSE) stopifnot(inherits(tabla, "lindey_frecuencia_agrupada"))
Creates Spanish-language frequency tables for grouped, discrete, or nominal data.
lindey_frecuencia_discreto( data, variable = NULL, valores_posibles = NULL, completar_valores = TRUE, max_completar = 100, orden = "valor", decimales_valor = "auto", decimales_porcentaje = 2, mostrar = TRUE )lindey_frecuencia_discreto( data, variable = NULL, valores_posibles = NULL, completar_valores = TRUE, max_completar = 100, orden = "valor", decimales_valor = "auto", decimales_porcentaje = 2, mostrar = TRUE )
data |
A vector or data frame containing the data to analyze. |
variable |
Optional variable name or column to analyze when 'data' is a data frame. |
valores_posibles |
Argument used by 'valores_posibles'. |
completar_valores |
Argument used by 'completar_valores'. |
max_completar |
Argument used by 'max_completar'. |
orden |
Argument used by 'orden'. |
decimales_valor |
Argument used by 'decimales_valor'. |
decimales_porcentaje |
Argument used by 'decimales_porcentaje'. |
mostrar |
Logical value indicating whether to print the formatted summary. |
An R object; see the function output for details.
mundoLindey
tabla <- lindey_frecuencia_discreto(c(1, 1, 2, 2, 3, 4), mostrar = FALSE) stopifnot(inherits(tabla, "lindey_frecuencia_discreto"))tabla <- lindey_frecuencia_discreto(c(1, 1, 2, 2, 3, 4), mostrar = FALSE) stopifnot(inherits(tabla, "lindey_frecuencia_discreto"))
Creates Spanish-language frequency tables for grouped, discrete, or nominal data.
lindey_frecuencia_nominal( data, variable = NULL, orden = "frecuencia", incluir_na = FALSE, etiqueta_na = "Sin dato", decimales_porcentaje = 2, mostrar = TRUE )lindey_frecuencia_nominal( data, variable = NULL, orden = "frecuencia", incluir_na = FALSE, etiqueta_na = "Sin dato", decimales_porcentaje = 2, mostrar = TRUE )
data |
A vector or data frame containing the data to analyze. |
variable |
Optional variable name or column to analyze when 'data' is a data frame. |
orden |
Argument used by 'orden'. |
incluir_na |
Argument used by 'incluir_na'. |
etiqueta_na |
Argument used by 'etiqueta_na'. |
decimales_porcentaje |
Argument used by 'decimales_porcentaje'. |
mostrar |
Logical value indicating whether to print the formatted summary. |
An R object; see the function output for details.
mundoLindey
tabla <- lindey_frecuencia_nominal(c("A", "B", "A", "C"), mostrar = FALSE) stopifnot(inherits(tabla, "lindey_frecuencia_nominal"))tabla <- lindey_frecuencia_nominal(c("A", "B", "A", "C"), mostrar = FALSE) stopifnot(inherits(tabla, "lindey_frecuencia_nominal"))
Creates a 'ggplot2' graphic from a frequency-table result produced by this package.
lindey_histograma( resultado, y = "fi", colores = "lindey", color_borde = "white", ancho_borde = 0.7, alpha = 0.95, leyenda = FALSE, titulo_leyenda = NULL, titulo = NULL, subtitulo = NULL, eje_x = NULL, eje_y = NULL, caption = "Elaborado con Mundo LINDEY", mostrar_valores = TRUE, etiqueta = "auto", posicion_etiqueta = "arriba", resaltar_moda = TRUE, color_moda_borde = "#0F172A", ancho_moda_borde = 1.2, mostrar_n = TRUE, mostrar_amplitud = TRUE, etiquetas_intervalo = TRUE, rotar_etiquetas_x = FALSE, expandir_y = 0.12, base_size = 12, fondo = "blanco" )lindey_histograma( resultado, y = "fi", colores = "lindey", color_borde = "white", ancho_borde = 0.7, alpha = 0.95, leyenda = FALSE, titulo_leyenda = NULL, titulo = NULL, subtitulo = NULL, eje_x = NULL, eje_y = NULL, caption = "Elaborado con Mundo LINDEY", mostrar_valores = TRUE, etiqueta = "auto", posicion_etiqueta = "arriba", resaltar_moda = TRUE, color_moda_borde = "#0F172A", ancho_moda_borde = 1.2, mostrar_n = TRUE, mostrar_amplitud = TRUE, etiquetas_intervalo = TRUE, rotar_etiquetas_x = FALSE, expandir_y = 0.12, base_size = 12, fondo = "blanco" )
resultado |
A result object returned by a mundoLindey frequency-table function. |
y |
Column or measure to show on the y-axis. |
colores |
Color palette name or vector of colors. |
color_borde |
Argument used by 'color_borde'. |
ancho_borde |
Argument used by 'ancho_borde'. |
alpha |
Argument used by 'alpha'. |
leyenda |
Argument used by 'leyenda'. |
titulo_leyenda |
Argument used by 'titulo_leyenda'. |
titulo |
Plot title. |
subtitulo |
Plot subtitle. |
eje_x |
Argument used by 'eje_x'. |
eje_y |
Argument used by 'eje_y'. |
caption |
Plot caption. |
mostrar_valores |
Argument used by 'mostrar_valores'. |
etiqueta |
Argument used by 'etiqueta'. |
posicion_etiqueta |
Argument used by 'posicion_etiqueta'. |
resaltar_moda |
Argument used by 'resaltar_moda'. |
color_moda_borde |
Argument used by 'color_moda_borde'. |
ancho_moda_borde |
Argument used by 'ancho_moda_borde'. |
mostrar_n |
Argument used by 'mostrar_n'. |
mostrar_amplitud |
Argument used by 'mostrar_amplitud'. |
etiquetas_intervalo |
Argument used by 'etiquetas_intervalo'. |
rotar_etiquetas_x |
Argument used by 'rotar_etiquetas_x'. |
expandir_y |
Argument used by 'expandir_y'. |
base_size |
Argument used by 'base_size'. |
fondo |
Argument used by 'fondo'. |
An R object; see the function output for details.
mundoLindey
datos <- c(8.5, 9.2, 10.1, 11.4, 12.8, 13.1, 14.7, 15.2, 16.9, 18.3) tabla <- lindey_frecuencia_agrupada(datos, mostrar = FALSE) grafico <- lindey_histograma(tabla) stopifnot(inherits(grafico, "lindey_grafico"))datos <- c(8.5, 9.2, 10.1, 11.4, 12.8, 13.1, 14.7, 15.2, 16.9, 18.3) tabla <- lindey_frecuencia_agrupada(datos, mostrar = FALSE) grafico <- lindey_histograma(tabla) stopifnot(inherits(grafico, "lindey_grafico"))
Creates a 'ggplot2' graphic from a frequency-table result produced by this package.
lindey_histograma_poligono( resultado, y = "fi", colores_barras = "suave", color_linea = "lindey", color_puntos = NULL, color_borde = "white", ancho_borde = 0.7, alpha_barras = 0.88, grosor_linea = 1.35, mostrar_puntos = TRUE, tamano_puntos = 3.8, relleno_puntos = "white", mostrar_valores = TRUE, etiqueta = "auto", resaltar_moda = TRUE, color_moda_borde = "#0F172A", ancho_moda_borde = 1.2, leyenda = FALSE, titulo_leyenda = "Intervalo", titulo = NULL, subtitulo = NULL, eje_x = NULL, eje_y = NULL, caption = "Elaborado con Mundo LINDEY", etiquetas_x = "intervalo", rotar_etiquetas_x = FALSE, expandir_y = 0.16, quitar_clases_vacias_finales = TRUE, base_size = 12, fondo = "blanco" )lindey_histograma_poligono( resultado, y = "fi", colores_barras = "suave", color_linea = "lindey", color_puntos = NULL, color_borde = "white", ancho_borde = 0.7, alpha_barras = 0.88, grosor_linea = 1.35, mostrar_puntos = TRUE, tamano_puntos = 3.8, relleno_puntos = "white", mostrar_valores = TRUE, etiqueta = "auto", resaltar_moda = TRUE, color_moda_borde = "#0F172A", ancho_moda_borde = 1.2, leyenda = FALSE, titulo_leyenda = "Intervalo", titulo = NULL, subtitulo = NULL, eje_x = NULL, eje_y = NULL, caption = "Elaborado con Mundo LINDEY", etiquetas_x = "intervalo", rotar_etiquetas_x = FALSE, expandir_y = 0.16, quitar_clases_vacias_finales = TRUE, base_size = 12, fondo = "blanco" )
resultado |
A result object returned by a mundoLindey frequency-table function. |
y |
Column or measure to show on the y-axis. |
colores_barras |
Argument used by 'colores_barras'. |
color_linea |
Argument used by 'color_linea'. |
color_puntos |
Argument used by 'color_puntos'. |
color_borde |
Argument used by 'color_borde'. |
ancho_borde |
Argument used by 'ancho_borde'. |
alpha_barras |
Argument used by 'alpha_barras'. |
grosor_linea |
Argument used by 'grosor_linea'. |
mostrar_puntos |
Argument used by 'mostrar_puntos'. |
tamano_puntos |
Argument used by 'tamano_puntos'. |
relleno_puntos |
Argument used by 'relleno_puntos'. |
mostrar_valores |
Argument used by 'mostrar_valores'. |
etiqueta |
Argument used by 'etiqueta'. |
resaltar_moda |
Argument used by 'resaltar_moda'. |
color_moda_borde |
Argument used by 'color_moda_borde'. |
ancho_moda_borde |
Argument used by 'ancho_moda_borde'. |
leyenda |
Argument used by 'leyenda'. |
titulo_leyenda |
Argument used by 'titulo_leyenda'. |
titulo |
Plot title. |
subtitulo |
Plot subtitle. |
eje_x |
Argument used by 'eje_x'. |
eje_y |
Argument used by 'eje_y'. |
caption |
Plot caption. |
etiquetas_x |
Argument used by 'etiquetas_x'. |
rotar_etiquetas_x |
Argument used by 'rotar_etiquetas_x'. |
expandir_y |
Argument used by 'expandir_y'. |
quitar_clases_vacias_finales |
Argument used by 'quitar_clases_vacias_finales'. |
base_size |
Argument used by 'base_size'. |
fondo |
Argument used by 'fondo'. |
An R object; see the function output for details.
mundoLindey
datos <- c(8.5, 9.2, 10.1, 11.4, 12.8, 13.1, 14.7, 15.2, 16.9, 18.3) tabla <- lindey_frecuencia_agrupada(datos, mostrar = FALSE) grafico <- lindey_histograma_poligono(tabla) stopifnot(inherits(grafico, "lindey_grafico"))datos <- c(8.5, 9.2, 10.1, 11.4, 12.8, 13.1, 14.7, 15.2, 16.9, 18.3) tabla <- lindey_frecuencia_agrupada(datos, mostrar = FALSE) grafico <- lindey_histograma_poligono(tabla) stopifnot(inherits(grafico, "lindey_grafico"))
Creates a 'ggplot2' graphic from a frequency-table result produced by this package.
lindey_ojiva( resultado, y = "Porcentaje_acumulado", color_linea = "lindey", color_puntos = NULL, grosor_linea = 1.3, tipo_linea = "solid", mostrar_puntos = TRUE, tamano_puntos = 3.8, forma_puntos = 21, relleno_puntos = "white", mostrar_valores = TRUE, etiqueta = "auto", incluir_origen = TRUE, referencia_mediana = TRUE, referencias = NULL, color_referencia = "#64748B", tipo_linea_referencia = "dashed", titulo = NULL, subtitulo = NULL, eje_x = NULL, eje_y = NULL, caption = "Elaborado con Mundo LINDEY", rotar_etiquetas_x = FALSE, expandir_y = 0.1, quitar_clases_vacias_finales = TRUE, base_size = 12, fondo = "blanco" )lindey_ojiva( resultado, y = "Porcentaje_acumulado", color_linea = "lindey", color_puntos = NULL, grosor_linea = 1.3, tipo_linea = "solid", mostrar_puntos = TRUE, tamano_puntos = 3.8, forma_puntos = 21, relleno_puntos = "white", mostrar_valores = TRUE, etiqueta = "auto", incluir_origen = TRUE, referencia_mediana = TRUE, referencias = NULL, color_referencia = "#64748B", tipo_linea_referencia = "dashed", titulo = NULL, subtitulo = NULL, eje_x = NULL, eje_y = NULL, caption = "Elaborado con Mundo LINDEY", rotar_etiquetas_x = FALSE, expandir_y = 0.1, quitar_clases_vacias_finales = TRUE, base_size = 12, fondo = "blanco" )
resultado |
A result object returned by a mundoLindey frequency-table function. |
y |
Column or measure to show on the y-axis. |
color_linea |
Argument used by 'color_linea'. |
color_puntos |
Argument used by 'color_puntos'. |
grosor_linea |
Argument used by 'grosor_linea'. |
tipo_linea |
Argument used by 'tipo_linea'. |
mostrar_puntos |
Argument used by 'mostrar_puntos'. |
tamano_puntos |
Argument used by 'tamano_puntos'. |
forma_puntos |
Argument used by 'forma_puntos'. |
relleno_puntos |
Argument used by 'relleno_puntos'. |
mostrar_valores |
Argument used by 'mostrar_valores'. |
etiqueta |
Argument used by 'etiqueta'. |
incluir_origen |
Argument used by 'incluir_origen'. |
referencia_mediana |
Argument used by 'referencia_mediana'. |
referencias |
Argument used by 'referencias'. |
color_referencia |
Argument used by 'color_referencia'. |
tipo_linea_referencia |
Argument used by 'tipo_linea_referencia'. |
titulo |
Plot title. |
subtitulo |
Plot subtitle. |
eje_x |
Argument used by 'eje_x'. |
eje_y |
Argument used by 'eje_y'. |
caption |
Plot caption. |
rotar_etiquetas_x |
Argument used by 'rotar_etiquetas_x'. |
expandir_y |
Argument used by 'expandir_y'. |
quitar_clases_vacias_finales |
Argument used by 'quitar_clases_vacias_finales'. |
base_size |
Argument used by 'base_size'. |
fondo |
Argument used by 'fondo'. |
An R object; see the function output for details.
mundoLindey
datos <- c(8.5, 9.2, 10.1, 11.4, 12.8, 13.1, 14.7, 15.2, 16.9, 18.3) tabla <- lindey_frecuencia_agrupada(datos, mostrar = FALSE) grafico <- lindey_ojiva(tabla) stopifnot(inherits(grafico, "lindey_grafico"))datos <- c(8.5, 9.2, 10.1, 11.4, 12.8, 13.1, 14.7, 15.2, 16.9, 18.3) tabla <- lindey_frecuencia_agrupada(datos, mostrar = FALSE) grafico <- lindey_ojiva(tabla) stopifnot(inherits(grafico, "lindey_grafico"))
Returns color palettes used by the mundoLindey graphics.
lindey_paleta( nombre = "lindey", n = 5 )lindey_paleta( nombre = "lindey", n = 5 )
nombre |
Argument used by 'nombre'. |
n |
Number of trials or observations. |
An R object; see the function output for details.
mundoLindey
colores <- lindey_paleta("lindey", 3) stopifnot(length(colores) == 3)colores <- lindey_paleta("lindey", 3) stopifnot(length(colores) == 3)
Creates a 'ggplot2' graphic from a frequency-table result produced by this package.
lindey_pastel( resultado, colores = "lindey", tipo = "pastel", leyenda = TRUE, titulo_leyenda = NULL, mostrar_etiquetas = TRUE, etiqueta = "porcentaje", min_porcentaje_etiqueta = 3, color_texto = "white", tamano_texto = NULL, fontface_texto = "bold", color_borde = "white", ancho_borde = 0.8, ordenar = TRUE, agrupar_menores = FALSE, min_porcentaje_otros = 3, etiqueta_otros = "Otros", titulo = NULL, subtitulo = NULL, caption = "Elaborado con Mundo LINDEY", base_size = 12, fondo = "blanco" )lindey_pastel( resultado, colores = "lindey", tipo = "pastel", leyenda = TRUE, titulo_leyenda = NULL, mostrar_etiquetas = TRUE, etiqueta = "porcentaje", min_porcentaje_etiqueta = 3, color_texto = "white", tamano_texto = NULL, fontface_texto = "bold", color_borde = "white", ancho_borde = 0.8, ordenar = TRUE, agrupar_menores = FALSE, min_porcentaje_otros = 3, etiqueta_otros = "Otros", titulo = NULL, subtitulo = NULL, caption = "Elaborado con Mundo LINDEY", base_size = 12, fondo = "blanco" )
resultado |
A result object returned by a mundoLindey frequency-table function. |
colores |
Color palette name or vector of colors. |
tipo |
Type of calculation or display to use. |
leyenda |
Argument used by 'leyenda'. |
titulo_leyenda |
Argument used by 'titulo_leyenda'. |
mostrar_etiquetas |
Argument used by 'mostrar_etiquetas'. |
etiqueta |
Argument used by 'etiqueta'. |
min_porcentaje_etiqueta |
Argument used by 'min_porcentaje_etiqueta'. |
color_texto |
Argument used by 'color_texto'. |
tamano_texto |
Argument used by 'tamano_texto'. |
fontface_texto |
Argument used by 'fontface_texto'. |
color_borde |
Argument used by 'color_borde'. |
ancho_borde |
Argument used by 'ancho_borde'. |
ordenar |
Argument used by 'ordenar'. |
agrupar_menores |
Argument used by 'agrupar_menores'. |
min_porcentaje_otros |
Argument used by 'min_porcentaje_otros'. |
etiqueta_otros |
Argument used by 'etiqueta_otros'. |
titulo |
Plot title. |
subtitulo |
Plot subtitle. |
caption |
Plot caption. |
base_size |
Argument used by 'base_size'. |
fondo |
Argument used by 'fondo'. |
An R object; see the function output for details.
mundoLindey
tabla <- lindey_frecuencia_nominal(c("A", "B", "A", "C"), mostrar = FALSE) grafico <- lindey_pastel(tabla) stopifnot(inherits(grafico, "lindey_grafico"))tabla <- lindey_frecuencia_nominal(c("A", "B", "A", "C"), mostrar = FALSE) grafico <- lindey_pastel(tabla) stopifnot(inherits(grafico, "lindey_grafico"))
Creates a 'ggplot2' graphic from a frequency-table result produced by this package.
lindey_pastel_discreto( resultado, ... )lindey_pastel_discreto( resultado, ... )
resultado |
A result object returned by a mundoLindey frequency-table function. |
... |
Additional arguments passed to methods or plotting functions. |
An R object; see the function output for details.
mundoLindey
tabla <- lindey_frecuencia_discreto(c(1, 1, 2, 2, 3, 4), mostrar = FALSE) grafico <- lindey_pastel_discreto(tabla) stopifnot(inherits(grafico, "lindey_grafico"))tabla <- lindey_frecuencia_discreto(c(1, 1, 2, 2, 3, 4), mostrar = FALSE) grafico <- lindey_pastel_discreto(tabla) stopifnot(inherits(grafico, "lindey_grafico"))
Creates a 'ggplot2' graphic from a frequency-table result produced by this package.
lindey_pastel_nominal( resultado, ... )lindey_pastel_nominal( resultado, ... )
resultado |
A result object returned by a mundoLindey frequency-table function. |
... |
Additional arguments passed to methods or plotting functions. |
An R object; see the function output for details.
mundoLindey
tabla <- lindey_frecuencia_nominal(c("A", "B", "A", "C"), mostrar = FALSE) grafico <- lindey_pastel_nominal(tabla) stopifnot(inherits(grafico, "lindey_grafico"))tabla <- lindey_frecuencia_nominal(c("A", "B", "A", "C"), mostrar = FALSE) grafico <- lindey_pastel_nominal(tabla) stopifnot(inherits(grafico, "lindey_grafico"))
Creates a 'ggplot2' graphic from a frequency-table result produced by this package.
lindey_poligono( resultado, y = "fi", color_linea = "lindey", color_puntos = NULL, color_area = NULL, grosor_linea = 1.3, tipo_linea = "solid", mostrar_puntos = TRUE, tamano_puntos = 3.8, forma_puntos = 21, relleno_puntos = "white", area = FALSE, alpha_area = 0.18, cerrar_poligono = TRUE, mostrar_valores = TRUE, etiqueta = "auto", titulo = NULL, subtitulo = NULL, eje_x = NULL, eje_y = NULL, caption = "Elaborado con Mundo LINDEY", etiquetas_x = "intervalo", rotar_etiquetas_x = FALSE, expandir_y = 0.16, resaltar_moda = TRUE, color_moda = "#0F172A", quitar_clases_vacias_finales = TRUE, base_size = 12, fondo = "blanco" )lindey_poligono( resultado, y = "fi", color_linea = "lindey", color_puntos = NULL, color_area = NULL, grosor_linea = 1.3, tipo_linea = "solid", mostrar_puntos = TRUE, tamano_puntos = 3.8, forma_puntos = 21, relleno_puntos = "white", area = FALSE, alpha_area = 0.18, cerrar_poligono = TRUE, mostrar_valores = TRUE, etiqueta = "auto", titulo = NULL, subtitulo = NULL, eje_x = NULL, eje_y = NULL, caption = "Elaborado con Mundo LINDEY", etiquetas_x = "intervalo", rotar_etiquetas_x = FALSE, expandir_y = 0.16, resaltar_moda = TRUE, color_moda = "#0F172A", quitar_clases_vacias_finales = TRUE, base_size = 12, fondo = "blanco" )
resultado |
A result object returned by a mundoLindey frequency-table function. |
y |
Column or measure to show on the y-axis. |
color_linea |
Argument used by 'color_linea'. |
color_puntos |
Argument used by 'color_puntos'. |
color_area |
Argument used by 'color_area'. |
grosor_linea |
Argument used by 'grosor_linea'. |
tipo_linea |
Argument used by 'tipo_linea'. |
mostrar_puntos |
Argument used by 'mostrar_puntos'. |
tamano_puntos |
Argument used by 'tamano_puntos'. |
forma_puntos |
Argument used by 'forma_puntos'. |
relleno_puntos |
Argument used by 'relleno_puntos'. |
area |
Argument used by 'area'. |
alpha_area |
Argument used by 'alpha_area'. |
cerrar_poligono |
Argument used by 'cerrar_poligono'. |
mostrar_valores |
Argument used by 'mostrar_valores'. |
etiqueta |
Argument used by 'etiqueta'. |
titulo |
Plot title. |
subtitulo |
Plot subtitle. |
eje_x |
Argument used by 'eje_x'. |
eje_y |
Argument used by 'eje_y'. |
caption |
Plot caption. |
etiquetas_x |
Argument used by 'etiquetas_x'. |
rotar_etiquetas_x |
Argument used by 'rotar_etiquetas_x'. |
expandir_y |
Argument used by 'expandir_y'. |
resaltar_moda |
Argument used by 'resaltar_moda'. |
color_moda |
Argument used by 'color_moda'. |
quitar_clases_vacias_finales |
Argument used by 'quitar_clases_vacias_finales'. |
base_size |
Argument used by 'base_size'. |
fondo |
Argument used by 'fondo'. |
An R object; see the function output for details.
mundoLindey
datos <- c(8.5, 9.2, 10.1, 11.4, 12.8, 13.1, 14.7, 15.2, 16.9, 18.3) tabla <- lindey_frecuencia_agrupada(datos, mostrar = FALSE) grafico <- lindey_poligono(tabla) stopifnot(inherits(grafico, "lindey_grafico"))datos <- c(8.5, 9.2, 10.1, 11.4, 12.8, 13.1, 14.7, 15.2, 16.9, 18.3) tabla <- lindey_frecuencia_agrupada(datos, mostrar = FALSE) grafico <- lindey_poligono(tabla) stopifnot(inherits(grafico, "lindey_grafico"))
Calculates probabilities for the binomial distribution and returns a Spanish-language summary with optional graphics.
lindey_prob_binomial( n, p, tipo = "menor", x = NULL, x1 = NULL, x2 = NULL, intervalo = "cerrado", formula = FALSE, decimales = 4, color_barras = "#CBD5E1", color_area = "#14B8A6", color_linea = "#F97316", color_media = "#475569", mostrar = TRUE )lindey_prob_binomial( n, p, tipo = "menor", x = NULL, x1 = NULL, x2 = NULL, intervalo = "cerrado", formula = FALSE, decimales = 4, color_barras = "#CBD5E1", color_area = "#14B8A6", color_linea = "#F97316", color_media = "#475569", mostrar = TRUE )
n |
Number of trials or observations. |
p |
Probability of success. |
tipo |
Type of calculation or display to use. |
x |
Numeric value, vector, or result object, depending on the selected function. |
x1 |
Lower value for interval probability calculations. |
x2 |
Upper value for interval probability calculations. |
intervalo |
Argument used by 'intervalo'. |
formula |
Logical value indicating whether to include formula text in the result. |
decimales |
Number of decimal places used in displayed results. |
color_barras |
Argument used by 'color_barras'. |
color_area |
Argument used by 'color_area'. |
color_linea |
Argument used by 'color_linea'. |
color_media |
Argument used by 'color_media'. |
mostrar |
Logical value indicating whether to print the formatted summary. |
An R object; see the function output for details.
mundoLindey
resultado <- lindey_prob_binomial(n = 10, p = 0.4, x = 3, mostrar = FALSE) stopifnot(inherits(resultado, "lindey_prob_binomial"))resultado <- lindey_prob_binomial(n = 10, p = 0.4, x = 3, mostrar = FALSE) stopifnot(inherits(resultado, "lindey_prob_binomial"))
Calculates probabilities for the binomial negativa distribution and returns a Spanish-language summary with optional graphics.
lindey_prob_binomial_negativa( r = NULL, size = NULL, p, parametrizacion = "fracasos", tipo = "menor", x = NULL, x1 = NULL, x2 = NULL, intervalo = "cerrado", formula = FALSE, decimales = 4, max_barras = 100, color_barras = "#CBD5E1", color_area = "#14B8A6", color_linea = "#F97316", color_media = "#475569", mostrar = TRUE )lindey_prob_binomial_negativa( r = NULL, size = NULL, p, parametrizacion = "fracasos", tipo = "menor", x = NULL, x1 = NULL, x2 = NULL, intervalo = "cerrado", formula = FALSE, decimales = 4, max_barras = 100, color_barras = "#CBD5E1", color_area = "#14B8A6", color_linea = "#F97316", color_media = "#475569", mostrar = TRUE )
r |
Number of successes. |
size |
Size parameter. |
p |
Probability of success. |
parametrizacion |
Argument used by 'parametrizacion'. |
tipo |
Type of calculation or display to use. |
x |
Numeric value, vector, or result object, depending on the selected function. |
x1 |
Lower value for interval probability calculations. |
x2 |
Upper value for interval probability calculations. |
intervalo |
Argument used by 'intervalo'. |
formula |
Logical value indicating whether to include formula text in the result. |
decimales |
Number of decimal places used in displayed results. |
max_barras |
Argument used by 'max_barras'. |
color_barras |
Argument used by 'color_barras'. |
color_area |
Argument used by 'color_area'. |
color_linea |
Argument used by 'color_linea'. |
color_media |
Argument used by 'color_media'. |
mostrar |
Logical value indicating whether to print the formatted summary. |
An R object; see the function output for details.
mundoLindey
resultado <- lindey_prob_binomial_negativa(r = 3, p = 0.4, x = 2, mostrar = FALSE) stopifnot(inherits(resultado, "lindey_prob_binomial_negativa"))resultado <- lindey_prob_binomial_negativa(r = 3, p = 0.4, x = 2, mostrar = FALSE) stopifnot(inherits(resultado, "lindey_prob_binomial_negativa"))
Calculates probabilities for the chi cuadrado distribution and returns a Spanish-language summary with optional graphics.
lindey_prob_chi_cuadrado( gl = NULL, df = NULL, tipo = "menor", x = NULL, x1 = NULL, x2 = NULL, intervalo = "abierto", formula = FALSE, decimales = 4, color_curva = "#0F172A", color_area = "#14B8A6", color_linea = "#F97316", color_media = "#475569", mostrar = TRUE )lindey_prob_chi_cuadrado( gl = NULL, df = NULL, tipo = "menor", x = NULL, x1 = NULL, x2 = NULL, intervalo = "abierto", formula = FALSE, decimales = 4, color_curva = "#0F172A", color_area = "#14B8A6", color_linea = "#F97316", color_media = "#475569", mostrar = TRUE )
gl |
Degrees of freedom. |
df |
Degrees of freedom. |
tipo |
Type of calculation or display to use. |
x |
Numeric value, vector, or result object, depending on the selected function. |
x1 |
Lower value for interval probability calculations. |
x2 |
Upper value for interval probability calculations. |
intervalo |
Argument used by 'intervalo'. |
formula |
Logical value indicating whether to include formula text in the result. |
decimales |
Number of decimal places used in displayed results. |
color_curva |
Argument used by 'color_curva'. |
color_area |
Argument used by 'color_area'. |
color_linea |
Argument used by 'color_linea'. |
color_media |
Argument used by 'color_media'. |
mostrar |
Logical value indicating whether to print the formatted summary. |
An R object; see the function output for details.
mundoLindey
resultado <- lindey_prob_chi_cuadrado(gl = 3, x = 2, mostrar = FALSE) stopifnot(inherits(resultado, "lindey_prob_chi_cuadrado"))resultado <- lindey_prob_chi_cuadrado(gl = 3, x = 2, mostrar = FALSE) stopifnot(inherits(resultado, "lindey_prob_chi_cuadrado"))
Calculates probabilities for the exponencial distribution and returns a Spanish-language summary with optional graphics.
lindey_prob_exponencial( lambda = NULL, media = NULL, tipo = "menor", x = NULL, x1 = NULL, x2 = NULL, intervalo = "abierto", formula = FALSE, decimales = 4, unidad = "unidades", color_curva = "#0F172A", color_area = "#14B8A6", color_linea = "#F97316", color_media = "#475569", mostrar = TRUE )lindey_prob_exponencial( lambda = NULL, media = NULL, tipo = "menor", x = NULL, x1 = NULL, x2 = NULL, intervalo = "abierto", formula = FALSE, decimales = 4, unidad = "unidades", color_curva = "#0F172A", color_area = "#14B8A6", color_linea = "#F97316", color_media = "#475569", mostrar = TRUE )
lambda |
Rate or mean parameter, depending on the distribution. |
media |
Mean parameter. |
tipo |
Type of calculation or display to use. |
x |
Numeric value, vector, or result object, depending on the selected function. |
x1 |
Lower value for interval probability calculations. |
x2 |
Upper value for interval probability calculations. |
intervalo |
Argument used by 'intervalo'. |
formula |
Logical value indicating whether to include formula text in the result. |
decimales |
Number of decimal places used in displayed results. |
unidad |
Argument used by 'unidad'. |
color_curva |
Argument used by 'color_curva'. |
color_area |
Argument used by 'color_area'. |
color_linea |
Argument used by 'color_linea'. |
color_media |
Argument used by 'color_media'. |
mostrar |
Logical value indicating whether to print the formatted summary. |
An R object; see the function output for details.
mundoLindey
resultado <- lindey_prob_exponencial(lambda = 0.5, x = 2, mostrar = FALSE) stopifnot(inherits(resultado, "lindey_prob_exponencial"))resultado <- lindey_prob_exponencial(lambda = 0.5, x = 2, mostrar = FALSE) stopifnot(inherits(resultado, "lindey_prob_exponencial"))
Calculates probabilities for the f distribution and returns a Spanish-language summary with optional graphics.
lindey_prob_f( gl1 = NULL, gl2 = NULL, df1 = NULL, df2 = NULL, tipo = "menor", x = NULL, x1 = NULL, x2 = NULL, intervalo = "abierto", formula = FALSE, decimales = 4, color_curva = "#0F172A", color_area = "#14B8A6", color_linea = "#F97316", color_media = "#475569", mostrar = TRUE )lindey_prob_f( gl1 = NULL, gl2 = NULL, df1 = NULL, df2 = NULL, tipo = "menor", x = NULL, x1 = NULL, x2 = NULL, intervalo = "abierto", formula = FALSE, decimales = 4, color_curva = "#0F172A", color_area = "#14B8A6", color_linea = "#F97316", color_media = "#475569", mostrar = TRUE )
gl1 |
First degrees-of-freedom parameter. |
gl2 |
Second degrees-of-freedom parameter. |
df1 |
First degrees-of-freedom parameter. |
df2 |
Second degrees-of-freedom parameter. |
tipo |
Type of calculation or display to use. |
x |
Numeric value, vector, or result object, depending on the selected function. |
x1 |
Lower value for interval probability calculations. |
x2 |
Upper value for interval probability calculations. |
intervalo |
Argument used by 'intervalo'. |
formula |
Logical value indicating whether to include formula text in the result. |
decimales |
Number of decimal places used in displayed results. |
color_curva |
Argument used by 'color_curva'. |
color_area |
Argument used by 'color_area'. |
color_linea |
Argument used by 'color_linea'. |
color_media |
Argument used by 'color_media'. |
mostrar |
Logical value indicating whether to print the formatted summary. |
An R object; see the function output for details.
mundoLindey
resultado <- lindey_prob_f(gl1 = 3, gl2 = 10, x = 2, mostrar = FALSE) stopifnot(inherits(resultado, "lindey_prob_f"))resultado <- lindey_prob_f(gl1 = 3, gl2 = 10, x = 2, mostrar = FALSE) stopifnot(inherits(resultado, "lindey_prob_f"))
Calculates probabilities for the geometrica 1 distribution and returns a Spanish-language summary with optional graphics.
lindey_prob_geometrica_1( p, tipo = "menor", x = NULL, x1 = NULL, x2 = NULL, intervalo = "cerrado", formula = FALSE, decimales = 4, max_barras = 80, color_barras = "#CBD5E1", color_area = "#14B8A6", color_linea = "#F97316", color_media = "#475569", mostrar = TRUE )lindey_prob_geometrica_1( p, tipo = "menor", x = NULL, x1 = NULL, x2 = NULL, intervalo = "cerrado", formula = FALSE, decimales = 4, max_barras = 80, color_barras = "#CBD5E1", color_area = "#14B8A6", color_linea = "#F97316", color_media = "#475569", mostrar = TRUE )
p |
Probability of success. |
tipo |
Type of calculation or display to use. |
x |
Numeric value, vector, or result object, depending on the selected function. |
x1 |
Lower value for interval probability calculations. |
x2 |
Upper value for interval probability calculations. |
intervalo |
Argument used by 'intervalo'. |
formula |
Logical value indicating whether to include formula text in the result. |
decimales |
Number of decimal places used in displayed results. |
max_barras |
Argument used by 'max_barras'. |
color_barras |
Argument used by 'color_barras'. |
color_area |
Argument used by 'color_area'. |
color_linea |
Argument used by 'color_linea'. |
color_media |
Argument used by 'color_media'. |
mostrar |
Logical value indicating whether to print the formatted summary. |
An R object; see the function output for details.
mundoLindey
resultado <- lindey_prob_geometrica_1(p = 0.25, x = 3, mostrar = FALSE) stopifnot(inherits(resultado, "lindey_prob_geometrica_1"))resultado <- lindey_prob_geometrica_1(p = 0.25, x = 3, mostrar = FALSE) stopifnot(inherits(resultado, "lindey_prob_geometrica_1"))
Calculates probabilities for the geometrica 2 distribution and returns a Spanish-language summary with optional graphics.
lindey_prob_geometrica_2( p, tipo = "menor", x = NULL, x1 = NULL, x2 = NULL, intervalo = "cerrado", formula = FALSE, decimales = 4, max_barras = 80, color_barras = "#CBD5E1", color_area = "#14B8A6", color_linea = "#F97316", color_media = "#475569", mostrar = TRUE )lindey_prob_geometrica_2( p, tipo = "menor", x = NULL, x1 = NULL, x2 = NULL, intervalo = "cerrado", formula = FALSE, decimales = 4, max_barras = 80, color_barras = "#CBD5E1", color_area = "#14B8A6", color_linea = "#F97316", color_media = "#475569", mostrar = TRUE )
p |
Probability of success. |
tipo |
Type of calculation or display to use. |
x |
Numeric value, vector, or result object, depending on the selected function. |
x1 |
Lower value for interval probability calculations. |
x2 |
Upper value for interval probability calculations. |
intervalo |
Argument used by 'intervalo'. |
formula |
Logical value indicating whether to include formula text in the result. |
decimales |
Number of decimal places used in displayed results. |
max_barras |
Argument used by 'max_barras'. |
color_barras |
Argument used by 'color_barras'. |
color_area |
Argument used by 'color_area'. |
color_linea |
Argument used by 'color_linea'. |
color_media |
Argument used by 'color_media'. |
mostrar |
Logical value indicating whether to print the formatted summary. |
An R object; see the function output for details.
mundoLindey
resultado <- lindey_prob_geometrica_2(p = 0.25, x = 3, mostrar = FALSE) stopifnot(inherits(resultado, "lindey_prob_geometrica_2"))resultado <- lindey_prob_geometrica_2(p = 0.25, x = 3, mostrar = FALSE) stopifnot(inherits(resultado, "lindey_prob_geometrica_2"))
Calculates probabilities for the hipergeometrica distribution and returns a Spanish-language summary with optional graphics.
lindey_prob_hipergeometrica( N, K, n, tipo = "menor", x = NULL, x1 = NULL, x2 = NULL, intervalo = "cerrado", formula = FALSE, decimales = 4, max_barras = 300, color_barras = "#CBD5E1", color_area = "#14B8A6", color_linea = "#F97316", color_media = "#475569", mostrar = TRUE )lindey_prob_hipergeometrica( N, K, n, tipo = "menor", x = NULL, x1 = NULL, x2 = NULL, intervalo = "cerrado", formula = FALSE, decimales = 4, max_barras = 300, color_barras = "#CBD5E1", color_area = "#14B8A6", color_linea = "#F97316", color_media = "#475569", mostrar = TRUE )
N |
Population size. |
K |
Number of success states in the population. |
n |
Number of trials or observations. |
tipo |
Type of calculation or display to use. |
x |
Numeric value, vector, or result object, depending on the selected function. |
x1 |
Lower value for interval probability calculations. |
x2 |
Upper value for interval probability calculations. |
intervalo |
Argument used by 'intervalo'. |
formula |
Logical value indicating whether to include formula text in the result. |
decimales |
Number of decimal places used in displayed results. |
max_barras |
Argument used by 'max_barras'. |
color_barras |
Argument used by 'color_barras'. |
color_area |
Argument used by 'color_area'. |
color_linea |
Argument used by 'color_linea'. |
color_media |
Argument used by 'color_media'. |
mostrar |
Logical value indicating whether to print the formatted summary. |
An R object; see the function output for details.
mundoLindey
resultado <- lindey_prob_hipergeometrica(N = 20, K = 7, n = 5, x = 2, mostrar = FALSE) stopifnot(inherits(resultado, "lindey_prob_hipergeometrica"))resultado <- lindey_prob_hipergeometrica(N = 20, K = 7, n = 5, x = 2, mostrar = FALSE) stopifnot(inherits(resultado, "lindey_prob_hipergeometrica"))
Calculates probabilities for the normal distribution and returns a Spanish-language summary with optional graphics.
lindey_prob_normal( media = 0, desviacion = 1, tipo = "menor", x = NULL, x1 = NULL, x2 = NULL, intervalo = "abierto", decimales = 4, color_curva = "#0F172A", color_area = "#14B8A6", color_linea = "#F97316", color_media = "#475569", mostrar = TRUE )lindey_prob_normal( media = 0, desviacion = 1, tipo = "menor", x = NULL, x1 = NULL, x2 = NULL, intervalo = "abierto", decimales = 4, color_curva = "#0F172A", color_area = "#14B8A6", color_linea = "#F97316", color_media = "#475569", mostrar = TRUE )
media |
Mean parameter. |
desviacion |
Standard deviation. |
tipo |
Type of calculation or display to use. |
x |
Numeric value, vector, or result object, depending on the selected function. |
x1 |
Lower value for interval probability calculations. |
x2 |
Upper value for interval probability calculations. |
intervalo |
Argument used by 'intervalo'. |
decimales |
Number of decimal places used in displayed results. |
color_curva |
Argument used by 'color_curva'. |
color_area |
Argument used by 'color_area'. |
color_linea |
Argument used by 'color_linea'. |
color_media |
Argument used by 'color_media'. |
mostrar |
Logical value indicating whether to print the formatted summary. |
An R object; see the function output for details.
mundoLindey
resultado <- lindey_prob_normal(media = 0, desviacion = 1, x = 1, mostrar = FALSE) stopifnot(inherits(resultado, "lindey_prob_normal"))resultado <- lindey_prob_normal(media = 0, desviacion = 1, x = 1, mostrar = FALSE) stopifnot(inherits(resultado, "lindey_prob_normal"))
Calculates probabilities for the poisson distribution and returns a Spanish-language summary with optional graphics.
lindey_prob_poisson( lambda = NULL, media = NULL, mu = NULL, tipo = "menor", x = NULL, x1 = NULL, x2 = NULL, intervalo = "cerrado", formula = FALSE, decimales = 4, max_barras = 120, color_barras = "#CBD5E1", color_area = "#14B8A6", color_linea = "#F97316", color_media = "#475569", mostrar = TRUE )lindey_prob_poisson( lambda = NULL, media = NULL, mu = NULL, tipo = "menor", x = NULL, x1 = NULL, x2 = NULL, intervalo = "cerrado", formula = FALSE, decimales = 4, max_barras = 120, color_barras = "#CBD5E1", color_area = "#14B8A6", color_linea = "#F97316", color_media = "#475569", mostrar = TRUE )
lambda |
Rate or mean parameter, depending on the distribution. |
media |
Mean parameter. |
mu |
Mean parameter. |
tipo |
Type of calculation or display to use. |
x |
Numeric value, vector, or result object, depending on the selected function. |
x1 |
Lower value for interval probability calculations. |
x2 |
Upper value for interval probability calculations. |
intervalo |
Argument used by 'intervalo'. |
formula |
Logical value indicating whether to include formula text in the result. |
decimales |
Number of decimal places used in displayed results. |
max_barras |
Argument used by 'max_barras'. |
color_barras |
Argument used by 'color_barras'. |
color_area |
Argument used by 'color_area'. |
color_linea |
Argument used by 'color_linea'. |
color_media |
Argument used by 'color_media'. |
mostrar |
Logical value indicating whether to print the formatted summary. |
An R object; see the function output for details.
mundoLindey
resultado <- lindey_prob_poisson(lambda = 3, x = 4, mostrar = FALSE) stopifnot(inherits(resultado, "lindey_prob_poisson"))resultado <- lindey_prob_poisson(lambda = 3, x = 4, mostrar = FALSE) stopifnot(inherits(resultado, "lindey_prob_poisson"))
Calculates probabilities for the t distribution and returns a Spanish-language summary with optional graphics.
lindey_prob_t( gl = NULL, df = NULL, tipo = "menor", x = NULL, x1 = NULL, x2 = NULL, intervalo = "abierto", formula = FALSE, decimales = 4, color_curva = "#0F172A", color_area = "#14B8A6", color_linea = "#F97316", color_media = "#475569", mostrar = TRUE )lindey_prob_t( gl = NULL, df = NULL, tipo = "menor", x = NULL, x1 = NULL, x2 = NULL, intervalo = "abierto", formula = FALSE, decimales = 4, color_curva = "#0F172A", color_area = "#14B8A6", color_linea = "#F97316", color_media = "#475569", mostrar = TRUE )
gl |
Degrees of freedom. |
df |
Degrees of freedom. |
tipo |
Type of calculation or display to use. |
x |
Numeric value, vector, or result object, depending on the selected function. |
x1 |
Lower value for interval probability calculations. |
x2 |
Upper value for interval probability calculations. |
intervalo |
Argument used by 'intervalo'. |
formula |
Logical value indicating whether to include formula text in the result. |
decimales |
Number of decimal places used in displayed results. |
color_curva |
Argument used by 'color_curva'. |
color_area |
Argument used by 'color_area'. |
color_linea |
Argument used by 'color_linea'. |
color_media |
Argument used by 'color_media'. |
mostrar |
Logical value indicating whether to print the formatted summary. |
An R object; see the function output for details.
mundoLindey
resultado <- lindey_prob_t(gl = 10, x = 1, mostrar = FALSE) stopifnot(inherits(resultado, "lindey_prob_t"))resultado <- lindey_prob_t(gl = 10, x = 1, mostrar = FALSE) stopifnot(inherits(resultado, "lindey_prob_t"))
Calculates or visualizes measures of central tendency for grouped data.
lindey_tendencia_agrupada( resultado, tipo = c("muestra", "poblacion"), decimales = 4, calcular_moda_multiple = FALSE, mostrar = TRUE )lindey_tendencia_agrupada( resultado, tipo = c("muestra", "poblacion"), decimales = 4, calcular_moda_multiple = FALSE, mostrar = TRUE )
resultado |
A result object returned by a mundoLindey frequency-table function. |
tipo |
Type of calculation or display to use. |
decimales |
Number of decimal places used in displayed results. |
calcular_moda_multiple |
Argument used by 'calcular_moda_multiple'. |
mostrar |
Logical value indicating whether to print the formatted summary. |
An R object; see the function output for details.
mundoLindey
datos <- c(8.5, 9.2, 10.1, 11.4, 12.8, 13.1, 14.7, 15.2, 16.9, 18.3) tabla <- lindey_frecuencia_agrupada(datos, mostrar = FALSE) tendencia <- lindey_tendencia_agrupada(tabla, mostrar = FALSE) stopifnot(inherits(tendencia, "lindey_tendencia_agrupada"))datos <- c(8.5, 9.2, 10.1, 11.4, 12.8, 13.1, 14.7, 15.2, 16.9, 18.3) tabla <- lindey_frecuencia_agrupada(datos, mostrar = FALSE) tendencia <- lindey_tendencia_agrupada(tabla, mostrar = FALSE) stopifnot(inherits(tendencia, "lindey_tendencia_agrupada"))
Calculates or visualizes measures of central tendency for grouped data.
lindey_tendencia_plot( x, tipo = c("muestra", "poblacion"), calcular_moda_multiple = TRUE, decimales = 2, tol = 1e-06, titulo = "Medidas de tendencia central", mostrar_valores = TRUE, mostrar_nota = TRUE, color_curva = "#D97706", color_relleno = "#F8E7C7", color_media = "#2563EB", color_mediana = "#F59E0B", color_moda = "#EF4444", color_texto = "#111827", mostrar = TRUE )lindey_tendencia_plot( x, tipo = c("muestra", "poblacion"), calcular_moda_multiple = TRUE, decimales = 2, tol = 1e-06, titulo = "Medidas de tendencia central", mostrar_valores = TRUE, mostrar_nota = TRUE, color_curva = "#D97706", color_relleno = "#F8E7C7", color_media = "#2563EB", color_mediana = "#F59E0B", color_moda = "#EF4444", color_texto = "#111827", mostrar = TRUE )
x |
Numeric value, vector, or result object, depending on the selected function. |
tipo |
Type of calculation or display to use. |
calcular_moda_multiple |
Argument used by 'calcular_moda_multiple'. |
decimales |
Number of decimal places used in displayed results. |
tol |
Argument used by 'tol'. |
titulo |
Plot title. |
mostrar_valores |
Argument used by 'mostrar_valores'. |
mostrar_nota |
Argument used by 'mostrar_nota'. |
color_curva |
Argument used by 'color_curva'. |
color_relleno |
Argument used by 'color_relleno'. |
color_media |
Argument used by 'color_media'. |
color_mediana |
Argument used by 'color_mediana'. |
color_moda |
Argument used by 'color_moda'. |
color_texto |
Argument used by 'color_texto'. |
mostrar |
Logical value indicating whether to print the formatted summary. |
An R object; see the function output for details.
mundoLindey
datos <- c(8.5, 9.2, 10.1, 11.4, 12.8, 13.1, 14.7, 15.2, 16.9, 18.3) tabla <- lindey_frecuencia_agrupada(datos, mostrar = FALSE) grafico <- lindey_tendencia_plot(tabla, mostrar = FALSE) stopifnot(inherits(grafico, "ggplot"))datos <- c(8.5, 9.2, 10.1, 11.4, 12.8, 13.1, 14.7, 15.2, 16.9, 18.3) tabla <- lindey_frecuencia_agrupada(datos, mostrar = FALSE) grafico <- lindey_tendencia_plot(tabla, mostrar = FALSE) stopifnot(inherits(grafico, "ggplot"))
Classifies variables and suggests suitable descriptive analyses and graphics.
lindey_tipo_variable( data, variable = NULL, ordinales = NULL, max_categorias_numerica = 10, mostrar = TRUE )lindey_tipo_variable( data, variable = NULL, ordinales = NULL, max_categorias_numerica = 10, mostrar = TRUE )
data |
A vector or data frame containing the data to analyze. |
variable |
Optional variable name or column to analyze when 'data' is a data frame. |
ordinales |
Argument used by 'ordinales'. |
max_categorias_numerica |
Argument used by 'max_categorias_numerica'. |
mostrar |
Logical value indicating whether to print the formatted summary. |
An R object; see the function output for details.
mundoLindey
datos <- data.frame(nota = c(12, 15, 14, 18)) resultado <- lindey_tipo_variable(datos, "nota", mostrar = FALSE) stopifnot(inherits(resultado, "lindey_tipo_variable"))datos <- data.frame(nota = c(12, 15, 14, 18)) resultado <- lindey_tipo_variable(datos, "nota", mostrar = FALSE) stopifnot(inherits(resultado, "lindey_tipo_variable"))
Returns a 'ggplot2' theme used by mundoLindey graphics.
theme_lindey( base_size = 12, base_family = "", fondo = "blanco", leyenda_posicion = "right" )theme_lindey( base_size = 12, base_family = "", fondo = "blanco", leyenda_posicion = "right" )
base_size |
Argument used by 'base_size'. |
base_family |
Argument used by 'base_family'. |
fondo |
Argument used by 'fondo'. |
leyenda_posicion |
Argument used by 'leyenda_posicion'. |
An R object; see the function output for details.
mundoLindey
tema <- theme_lindey() stopifnot(inherits(tema, "theme"))tema <- theme_lindey() stopifnot(inherits(tema, "theme"))
Returns a 'ggplot2' theme used by mundoLindey graphics.
theme_lindey_pastel( base_size = 12, fondo = "blanco", leyenda_posicion = "right" )theme_lindey_pastel( base_size = 12, fondo = "blanco", leyenda_posicion = "right" )
base_size |
Argument used by 'base_size'. |
fondo |
Argument used by 'fondo'. |
leyenda_posicion |
Argument used by 'leyenda_posicion'. |
An R object; see the function output for details.
mundoLindey
tema <- theme_lindey_pastel() stopifnot(inherits(tema, "theme"))tema <- theme_lindey_pastel() stopifnot(inherits(tema, "theme"))
Returns a 'ggplot2' theme used by mundoLindey graphics.
theme_lindey_prob( base_size = 13 )theme_lindey_prob( base_size = 13 )
base_size |
Argument used by 'base_size'. |
An R object; see the function output for details.
mundoLindey
tema <- theme_lindey_prob() stopifnot(inherits(tema, "theme"))tema <- theme_lindey_prob() stopifnot(inherits(tema, "theme"))